@@ -31,12 +31,12 @@ static GnomeUIInfo fileopenmenu[] = {
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo filemenu[] = {
-	GNOMEUIINFO_SUBTREE_STOCK(N_("New"), filenewmenu, GNOME_STOCK_MENU_NEW),
-	GNOMEUIINFO_SUBTREE_STOCK(N_("Open"), fileopenmenu, GNOME_STOCK_MENU_OPEN),
+	GNOMEUIINFO_SUBTREE_STOCK(N_("_New"), filenewmenu, GNOME_STOCK_MENU_NEW),
+	GNOMEUIINFO_SUBTREE_STOCK(N_("_Open"), fileopenmenu, GNOME_STOCK_MENU_OPEN),
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo mainmenu[] = {
-	GNOMEUIINFO_SUBTREE(N_("File"), filemenu),
+	GNOMEUIINFO_SUBTREE(N_("_File"), filemenu),
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo toolbar[] = {
@@ -52,22 +52,23 @@ static GnomeUIInfo toolbar[] = {
 /*
  * Public functions
  */
-GnomeDbControlInstance *
-builder_control_create_instance (GnomeDbControl *control) {
-	GtkWidget*              w;
-	GnomeDbControlInstance* control_instance;
+BonoboObject *
+builder_control_new (void)
+{
+	GtkWidget*      w;
+	GnomeDbControl* control;
 	
 	/* create builder main widget */
 	w = gnome_db_new_table_widget(8, 8, FALSE);
 	gtk_widget_show_all(w);
 	
 	/* create control instance */
-	control_instance = gnome_db_control_instance_new(control, w);
-	if (GNOME_DB_IS_CONTROL_INSTANCE(control_instance)) {
+	control = gnome_db_control_new(w);
+	if (GNOME_DB_IS_CONTROL(control)) {
 		/* set menus/toolbar */
-		gnome_db_control_instance_set_menubar(control_instance, mainmenu);
-		gnome_db_control_instance_set_toolbar(control_instance, toolbar);
+		gnome_db_control_set_menubar(control, mainmenu);
+		gnome_db_control_set_toolbar(control, toolbar);
 	}
 	
-	return control_instance;
+	return BONOBO_OBJECT(control);
 }
