@@ -16,14 +16,15 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
  
-#include <gnomedb-builder.h>
+#include "gnomedb-builder.h"
 
 static guint prepare_app (void);
 
-GnomeDbControl* builder_control = NULL;
+BonoboGenericFactory* builder_factory = NULL;
 
 int
-main (int argc, char *argv) {
+main (int argc, char *argv[])
+{
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 	
@@ -34,13 +35,26 @@ main (int argc, char *argv) {
 	return 0;
 }
 
+static BonoboObject *
+builder_factory_func (BonoboGenericFactory *factory, const char *id, gpointer closure)
+{
+	g_return_val_if_fail(BONOBO_IS_GENERIC_FACTORY(factory), NULL);
+	g_return_val_if_fail(id != NULL, NULL);
+	
+	if (!strcmp(id, GNOME_DB_OAFIID_BUILDER))
+		return builder_control_new();
+
+	return NULL;
+}
+
 static guint
-prepare_app (void) {
-	/* create control factory */
-	builder_control = gnome_db_control_new("OAFIID:GNOME_DB_Builder_ControlFactory",
-	                                       builder_control_create_instance);
-	if (!GNOME_DB_IS_CONTROL(builder_control)) {
-		g_error(_("Could not initialize GNOME_DB_Builder control"));
-	}
+prepare_app (void)
+{
+	/* create builder factory */
+	builder_factory = bonobo_generic_factory_new_multi(GNOME_DB_OAFIID_BUILDER_FACTORY,
+	                                                   builder_factory_func,
+	                                                   NULL);
+	bonobo_running_context_auto_exit_unref(BONOBO_OBJECT(builder_factory));
+
 	return FALSE;
 }
