@@ -31,7 +31,7 @@ BEGIN_GNOME_DECLS
 /*
  * Main control
  */
-GnomeDbControlInstance* builder_control_create_instance (GnomeDbControl *control);
+BonoboObject* builder_control_new (void);
 
 /*
  * Configuration
