@@ -22,7 +22,8 @@ static GList* last_commands = NULL;
 static gint   max_last_command = 100;
 
 GList *
-components_config_get_last_commands (void) {
+components_config_get_last_commands (void)
+{
 	if (!last_commands) {
 		gint cnt;
 		
@@ -38,7 +39,8 @@ components_config_get_last_commands (void) {
 }
 
 void
-components_config_add_last_command (const gchar *cmd) {
+components_config_add_last_command (const gchar *cmd)
+{
 	static gint times_count = 0;
 	
 	g_return_if_fail(cmd != NULL);
