@@ -21,12 +21,14 @@
 static GList* activated_components = NULL;
 
 void
-fe_about_cb (GtkWidget *w, gpointer user_data) {
+fe_about_cb (GtkWidget *w, gpointer user_data)
+{
 	gnome_db_show_about_dialog("GNOME-DB Front End");
 }
 
 void
-fe_activate_component_cb (GtkWidget *w, gpointer user_data) {
+fe_activate_component_cb (GtkWidget *w, gpointer user_data)
+{
 	GnomeDbControlWidget* wid = NULL;
 	GList*                node;
 	
@@ -53,7 +55,8 @@ fe_activate_component_cb (GtkWidget *w, gpointer user_data) {
 }
 
 void
-fe_do_copy_clipboard_cb (GtkWidget *w, gpointer user_data) {
+fe_do_copy_clipboard_cb (GtkWidget *w, gpointer user_data)
+{
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
 		gnome_db_control_widget_do_copy_clipboard(GNOME_DB_CONTROL_WIDGET(tab));
@@ -61,7 +64,8 @@ fe_do_copy_clipboard_cb (GtkWidget *w, gpointer user_data) {
 }
 
 void
-fe_do_cut_clipboard_cb (GtkWidget *w, gpointer user_data) {
+fe_do_cut_clipboard_cb (GtkWidget *w, gpointer user_data)
+{
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
 		gnome_db_control_widget_do_cut_clipboard(GNOME_DB_CONTROL_WIDGET(tab));
@@ -69,7 +73,8 @@ fe_do_cut_clipboard_cb (GtkWidget *w, gpointer user_data) {
 }
 
 void
-fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data) {
+fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data)
+{
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
 		gnome_db_control_widget_do_paste_clipboard(GNOME_DB_CONTROL_WIDGET(tab));
@@ -77,7 +82,8 @@ fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data) {
 }
 
 void
-fe_do_print_cb (GtkWidget *w, gpointer user_data) {
+fe_do_print_cb (GtkWidget *w, gpointer user_data)
+{
 	GtkWidget* tab = fe_workarea_get_current_tab();
 	if (GNOME_DB_IS_CONTROL_WIDGET(tab)) {
 		gnome_db_control_widget_do_print(GNOME_DB_CONTROL_WIDGET(tab));
@@ -85,14 +91,72 @@ fe_do_print_cb (GtkWidget *w, gpointer user_data) {
 }
 
 void
-fe_preferences_cb (GtkWidget *w, gpointer user_data) {
+fe_new_database_cb (GtkWidget *w, gpointer user_data)
+{
+	fe_wizard_new_database();
+}
+
+void
+fe_open_gnome_db_manual_cb (GtkWidget *w, gpointer user_data)
+{
+	gchar *filename;
+
+	filename = gnome_help_file_find_file("gnome-db", "index.html");
+	if (filename) {
+		gnome_help_goto(NULL, filename);
+		g_free((gpointer) filename);
+	}
+}
+
+void
+fe_open_libgda_manual_cb (GtkWidget *w, gpointer user_data)
+{
+	gchar *filename;
+
+	filename = gnome_help_file_find_file("libgda", "index.html");
+	if (filename) {
+		gnome_help_goto(NULL, filename);
+		g_free((gpointer) filename);
+	}
+}
+
+void
+fe_open_libgda_reference_cb (GtkWidget *w, gpointer user_data)
+{
+	gchar *filename;
+
+	filename = gnome_help_file_find_file("libgda-reference", "libgda-reference.html");
+	if (filename) {
+		gnome_help_goto(NULL, filename);
+		g_free((gpointer) filename);
+	}
+}
+
+void
+fe_preferences_cb (GtkWidget *w, gpointer user_data)
+{
 	fe_config_open_dialog();
 }
 
 void
-fe_quit_cb (GtkWidget *w, gpointer user_data) {
+fe_quit_cb (GtkWidget *w, gpointer user_data)
+{
 	fe_config_save();
 	gnome_db_main_quit();
 }
 
+#if defined(HAVE_PERL)
+void
+fe_run_perl_cb (GtkWidget *w, gpointer data)
+{
+	gchar *filename;
 
+	filename = gnome_db_select_file(_("Open Perl script"));
+	if (filename) {
+		gchar *args[] = { "", NULL, NULL };
+		args[1] = filename;
+	    fe_perl_run(2, args);
+		g_free((gpointer) filename);
+	}
+}
+#endif
