@@ -21,21 +21,24 @@
 void
 fe_config_load (void)
 {
-  /* generate default configuration if it's the first time */
-  if (!gda_config_has_section(GNOMEDB_FE_CONFIG_SECTION_MAIN)) {
-  	gda_config_set_boolean(GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS, TRUE);
-  }
-  if (!gda_config_has_section(GNOMEDB_FE_CONFIG_SECTION_LOAD)) {
-  	gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_LOG_VIEWER, GNOME_DB_OAFIID_LOG_VIEWER);
-  	gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_MANAGER, GNOME_DB_OAFIID_MANAGER);
-  	gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_CONNECTION, GNOME_DB_OAFIID_CONNECTION);
-  	gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_HELP_VIEWER, GNOME_DB_OAFIID_HELP_VIEWER);
-  	gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_DESIGNER, GNOME_DB_OAFIID_DESIGNER);
-    }
+	/* generate default configuration if it's the first time */
+	if (!gda_config_has_section(GNOMEDB_FE_CONFIG_SECTION_MAIN)) {
+		gda_config_set_boolean(GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS, TRUE);
+		gda_config_set_boolean(GNOME_DB_CONFIG_KEY_SHOW_TOOLTIPS, TRUE);
+	}
+
+	/* now, default components to be loaded */
+	if (!gda_config_has_section(GNOMEDB_FE_CONFIG_SECTION_LOAD)) {
+		gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_LOG_VIEWER, GNOME_DB_OAFIID_LOG_VIEWER);
+		gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_MANAGER, GNOME_DB_OAFIID_MANAGER);
+		gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_CONNECTION, GNOME_DB_OAFIID_CONNECTION);
+		gda_config_set_string(GNOMEDB_FE_CONFIG_SECTION_LOAD "/" GNOME_DB_OAFIID_DESIGNER, GNOME_DB_OAFIID_DESIGNER);
+	}
 }
 
 void
-fe_config_save (void) {
+fe_config_save (void)
+{
 	/* save UI settings */
 	if (gda_config_get_boolean(GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS))
 		gnome_db_save_window_config("MainWindow", glb_mainwin);
@@ -45,7 +48,8 @@ fe_config_save (void) {
  * Configuration dialog
  */
 static void
-fill_shell_components_list (GtkCList *clist) {
+fill_shell_components_list (GtkCList *clist)
+{
 	GList* shell_com_list;
 	
 	g_return_if_fail(GTK_IS_CLIST(clist));
@@ -86,7 +90,8 @@ fill_shell_components_list (GtkCList *clist) {
 }
 
 static void
-set_load_component_cb (GtkWidget *w, GtkCList *clist) {
+set_load_component_cb (GtkWidget *w, GtkCList *clist)
+{
 	GnomePixmap* pixmap;
 	GList*       selected;
 	
@@ -103,7 +108,8 @@ set_load_component_cb (GtkWidget *w, GtkCList *clist) {
 }
 
 static void
-set_unload_component_cb (GtkWidget *w, GtkCList *clist) {
+set_unload_component_cb (GtkWidget *w, GtkCList *clist)
+{
 	GnomePixmap* pixmap;
 	GList*       selected;
 	
@@ -120,7 +126,8 @@ set_unload_component_cb (GtkWidget *w, GtkCList *clist) {
 }
 
 static GtkWidget *
-components_init (GtkNotebook *notebook) {
+components_init (GtkNotebook *notebook)
+{
 	GtkWidget* table;
 	GtkWidget* scroll;
 	GtkWidget* clist;
@@ -160,7 +167,8 @@ components_init (GtkNotebook *notebook) {
 }
 
 static void
-components_save (GtkWidget *tab) {
+components_save (GtkWidget *tab)
+{
 	GtkWidget*   clist;
 	GnomePixmap* active_pixmap;
 	
@@ -196,158 +204,63 @@ components_save (GtkWidget *tab) {
 }
 
 static GtkWidget *
-general_init (GtkNotebook *notebook) {
+general_init (GtkNotebook *notebook)
+{
 	GtkWidget* table;
 	GtkWidget* save_window_pos;
+	GtkWidget* show_tooltips;
 	
 	g_return_val_if_fail(GTK_IS_NOTEBOOK(notebook), NULL);
 	
 	table = gnome_db_new_table_widget(4, 10, FALSE);
 	gtk_notebook_append_page(notebook, table, gtk_label_new(_("General")));
-	
+
+	/* 'save window position' option */
 	save_window_pos = gnome_db_new_check_button_widget(_("Save window position"),
 	                                                   gda_config_get_boolean(GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS));
+	gnome_db_set_widget_tooltip(save_window_pos, _("If enabled, save the window position on exit"));
 	gtk_object_set_data(GTK_OBJECT(table), "FE_Config_SaveWindowPos", (gpointer) save_window_pos);
 	gtk_table_attach(GTK_TABLE(table), save_window_pos, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
+
+	/* 'show tooltips' option */
+	show_tooltips = gnome_db_new_check_button_widget(_("Show tooltips"),
+													 gda_config_get_boolean(GNOME_DB_CONFIG_KEY_SHOW_TOOLTIPS));
+	gnome_db_set_widget_tooltip(show_tooltips, _("Show tooltips for UI widgets"));
+	gtk_object_set_data(GTK_OBJECT(table), "FE_Config_ShowTooltips", (gpointer) show_tooltips);
+	gtk_table_attach(GTK_TABLE(table), show_tooltips, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
+ 
 	return table;
 }
 
 static void
-general_save (GtkWidget *tab) {
-	GtkWidget* save_window_pos;
+general_save (GtkWidget *tab)
+{
+	GtkWidget* w;
 	
 	g_return_if_fail(GTK_IS_WIDGET(tab));
 	
 	/* SaveWindowPos -> save main window position for future sessions */
-	save_window_pos = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_SaveWindowPos");
-	if (GTK_IS_CHECK_BUTTON(save_window_pos)) {
+	w = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_SaveWindowPos");
+	if (GTK_IS_CHECK_BUTTON(w)) {
 		gda_config_set_boolean(GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS,
-		                       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(save_window_pos)));
+		                       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)));
 	}
-}
 
-static void
-set_help_home_cb (GtkButton *button, GtkWidget *tab) {
-	GtkWidget* clist;
-	GtkWidget* entry;
-	
-	g_return_if_fail(GTK_IS_WIDGET(tab));
-	
-	clist = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_HelpViewerDocs");
-	if (GTK_IS_CLIST(clist)) {
-		entry = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_HelpViewerHome");
-		if (GTK_IS_ENTRY(entry)) {
-			gchar* url = NULL;
-			if (GTK_CLIST(clist)->selection) {
-				if (gtk_clist_get_text(GTK_CLIST(clist),
-				                       GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data),
-				                       2, &url)) {
-					gtk_entry_set_text(GTK_ENTRY(entry), url);
-				}
-			}
-		}
-	}
-}
-
-static GtkWidget *
-help_init (GtkNotebook *notebook) {
-	GtkWidget* table;
-	GtkWidget* scroll;
-	GtkWidget* clist;
-	GList*     entries;
-	GList*     node;
-	GtkWidget* label;
-	GtkWidget* entry;
-	GtkWidget* button;
-	
-	g_return_val_if_fail(GTK_IS_NOTEBOOK(notebook), NULL);
-	
-	table = gnome_db_new_table_widget(4, 8, FALSE);
-	gtk_notebook_append_page(notebook, table, gtk_label_new(_("Help System")));
-	
-	label = gnome_db_new_label_widget(_("Home page"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
-	entry = gnome_db_new_entry_widget(0, TRUE);
-	gtk_object_set_data(GTK_OBJECT(table), "FE_Config_HelpViewerHome", (gpointer) entry);
-	gtk_entry_set_text(GTK_ENTRY(entry), gnome_db_help_get_home());
-	gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
-	
-	/* create list */
-	scroll = gnome_db_new_scrolled_window_widget();
-	gtk_table_attach(GTK_TABLE(table), scroll, 0, 3, 1, 8,
-	                 GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-	                 GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-	                 3, 3);
-	clist = gnome_db_new_clist_widget(NULL, 3);
-	gtk_object_set_data(GTK_OBJECT(table), "FE_Config_HelpViewerDocs", (gpointer) clist);
-	gtk_container_add(GTK_CONTAINER(scroll), clist);
-	
-	/* search for installed documentation */
-	gtk_clist_freeze(GTK_CLIST(clist));
-	entries = gda_config_list_keys(GNOME_DB_CONFIG_SECTION_HELP_VIEWER_DOCS);
-	for (node = g_list_first(entries); node != NULL; node = node->next) {
-		gchar* title = (gchar *) node->data;
-		if (title) {
-			gchar* url;
-			gchar* entry = g_strdup_printf("%s/%s", GNOME_DB_CONFIG_SECTION_HELP_VIEWER_DOCS, title);
-			url = gda_config_get_string(entry);
-			if (url) {
-				gchar*       row[3];
-				gint         row_number;
-				GnomePixmap* pixmap;
-				
-				row[0] = "";
-				row[1] = title;
-				row[2] = url;
-				row_number = gtk_clist_append(GTK_CLIST(clist), row);
-				
-				pixmap = gnome_db_get_pixmap(GNOME_STOCK_MENU_BOOK_OPEN);
-				if (pixmap) {
-					gtk_clist_set_pixmap(GTK_CLIST(clist), row_number, 0, pixmap->pixmap, pixmap->mask);
-				}
-			}
-		}
-	}
-	gtk_clist_thaw(GTK_CLIST(clist));
-	
-	button = gnome_db_new_button_widget_with_pixmap(_("Install"), GNOME_STOCK_MENU_NEW);
-	gtk_table_attach(GTK_TABLE(table), button, 3, 4, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
-	
-	button = gnome_db_new_button_widget_with_pixmap(_("Uninstall"), GNOME_STOCK_MENU_TRASH);
-	gtk_table_attach(GTK_TABLE(table), button, 3, 4, 2, 3, GTK_FILL, GTK_FILL, 3, 3);
-	
-	button = gnome_db_new_button_widget_with_pixmap(_("Edit"), GNOME_STOCK_MENU_PROP);
-	gtk_table_attach(GTK_TABLE(table), button, 3, 4, 3, 4, GTK_FILL, GTK_FILL, 3, 3);
-	
-	button = gnome_db_new_button_widget_with_pixmap(_("Set as Home"), GNOME_STOCK_MENU_HOME);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(set_help_home_cb), table);
-	gtk_table_attach(GTK_TABLE(table), button, 3, 4, 4, 5, GTK_FILL, GTK_FILL, 3, 3);
-	
-	return table;
-}
-
-static void
-help_save (GtkWidget *tab) {
-	GtkWidget* w;
-	gchar*     str;
-	
-	g_return_if_fail(GTK_IS_WIDGET(tab));
-	
-	w = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_HelpViewerHome");
-	if (GTK_IS_ENTRY(w)) {
-		str = gtk_entry_get_text(GTK_ENTRY(w));
-		if (str) gda_config_set_string(GNOME_DB_CONFIG_KEY_HELP_VIEWER_HOME, str);
-		else gda_config_remove_key(GNOME_DB_CONFIG_KEY_HELP_VIEWER_HOME);
+	/* ShowTooltips -> show tooltips on UI widgets */
+	w = gtk_object_get_data(GTK_OBJECT(tab), "FE_Config_ShowTooltips");
+	if (GTK_IS_CHECK_BUTTON(w)) {
+		gda_config_set_boolean(GNOME_DB_CONFIG_KEY_SHOW_TOOLTIPS,
+							   gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w)));
 	}
 }
 
 void
-fe_config_open_dialog (void) {
+fe_config_open_dialog (void)
+{
 	GtkWidget* dialog;
 	GtkWidget* notebook;
 	GtkWidget* com_tab;
 	GtkWidget* general_tab;
-	GtkWidget* help_tab;
 	
 	/* create dialog */
 	dialog = gnome_dialog_new(_("Preferences"), GNOME_STOCK_BUTTON_OK, GNOME_STOCK_BUTTON_CANCEL, NULL);
@@ -357,12 +270,10 @@ fe_config_open_dialog (void) {
 	
 	general_tab = general_init(GTK_NOTEBOOK(notebook));
 	com_tab = components_init(GTK_NOTEBOOK(notebook));
-	help_tab = help_init(GTK_NOTEBOOK(notebook));
 	
 	if (!gnome_dialog_run(GNOME_DIALOG(dialog))) {
 		general_save(general_tab);
 		components_save(com_tab);
-		help_save(help_tab);
 	}
 	gnome_dialog_close(GNOME_DIALOG(dialog));
 }
