@@ -27,21 +27,32 @@ GtkWidget* glb_mainwin = NULL;
 
 /* menus */
 static GnomeUIInfo filenewmenu[] = {
+	{ GNOME_APP_UI_ITEM, N_("_Database..."), N_("Create a new database"),
+	  fe_new_database_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GNOME_STOCK_MENU_MAIL, 0, 0, NULL },
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo fileopenmenu[] = {
+#if defined(HAVE_PERL)
+	{ GNOME_APP_UI_ITEM, N_("Perl script"), N_("Open a Perl script to be executed"),
+	  fe_run_perl_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
+#endif
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo filemenu[] = {
-	GNOMEUIINFO_SUBTREE_STOCK(N_("New"), filenewmenu, GNOME_STOCK_MENU_NEW),
-	GNOMEUIINFO_SUBTREE_STOCK(N_("Open"), filenewmenu, GNOME_STOCK_MENU_OPEN),
+	GNOMEUIINFO_SUBTREE_STOCK(N_("_New"), filenewmenu, GNOME_STOCK_MENU_NEW),
+	GNOMEUIINFO_SUBTREE_STOCK(N_("_Open"), fileopenmenu, GNOME_STOCK_MENU_OPEN),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_PRINT_ITEM(fe_do_print_cb, NULL),
+	{ GNOME_APP_UI_ITEM, N_("Print preview"), N_("Print preview"),
+	  NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+	  GNOME_STOCK_MENU_SEARCH, GNOME_APP_CONFIGURABLE_ITEM_FIND, 0, NULL },
 	GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(gnome_db_print_setup_dlg_cb, NULL),
 	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("Quit"), N_("Exit application"),
+	{ GNOME_APP_UI_ITEM, N_("_Quit"), N_("Exit application"),
 	  fe_quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_MENU_QUIT, 0, 0, NULL },
+	  GNOME_STOCK_MENU_QUIT, GNOME_APP_CONFIGURABLE_ITEM_EXIT, 0, NULL },
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo editmenu[] = {
@@ -53,16 +64,28 @@ static GnomeUIInfo editmenu[] = {
 static GnomeUIInfo databasemenu[] = {
 	GNOMEUIINFO_END
 };
+static GnomeUIInfo toolsmenu[] = {
+	GNOMEUIINFO_END
+};
 static GnomeUIInfo optionsmenu[] = {
 	{ GNOME_APP_UI_ITEM, N_("Preferences"), N_("Configure user preferences"),
 	  fe_preferences_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_MENU_PREF, 0, 0, NULL },
+	  GNOME_STOCK_MENU_PREF, GNOME_APP_CONFIGURABLE_ITEM_PREFERENCES, 0, NULL },
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo helpmenu[] = {
+	{ GNOME_APP_UI_ITEM, N_("GNOME-DB Manual"), N_("Open the GNOME-DB online manual"),
+	  fe_open_gnome_db_manual_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("libgda Manual"), N_("Open the libgda online manual"),
+	  fe_open_libgda_manual_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("libgda API Reference"), N_("Open the libgda API reference"),
+	  fe_open_libgda_reference_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
 	{ GNOME_APP_UI_ITEM, N_("About GNOME-DB..."), N_("View information about this application"),
 	  fe_about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-	  GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
+	  GNOME_STOCK_MENU_ABOUT, GNOME_APP_CONFIGURABLE_ITEM_ABOUT, 0, NULL },
 	GNOMEUIINFO_SEPARATOR,
 	{ GNOME_APP_UI_ITEM, N_("Submit bug report"), N_("Send a bug report to GNOME-DB developers"),
 	  gnome_db_submit_bug_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
@@ -70,11 +93,12 @@ static GnomeUIInfo helpmenu[] = {
 	GNOMEUIINFO_END
 };
 static GnomeUIInfo mainmenu[] = {
-	GNOMEUIINFO_SUBTREE(N_("File"), filemenu),
-	GNOMEUIINFO_SUBTREE(N_("Edit"), editmenu),
-	GNOMEUIINFO_SUBTREE(N_("Database"), databasemenu),
-	GNOMEUIINFO_SUBTREE(N_("Options"), optionsmenu),
-	GNOMEUIINFO_SUBTREE(N_("Help"), helpmenu),
+	GNOMEUIINFO_SUBTREE(N_("_File"), filemenu),
+	GNOMEUIINFO_SUBTREE(N_("_Edit"), editmenu),
+	GNOMEUIINFO_SUBTREE(N_("_Database"), databasemenu),
+	GNOMEUIINFO_SUBTREE(N_("_Tools"), toolsmenu),
+	GNOMEUIINFO_SUBTREE(N_("_Options"), optionsmenu),
+	GNOMEUIINFO_SUBTREE(N_("_Help"), helpmenu),
 	GNOMEUIINFO_END
 };
 
@@ -85,20 +109,29 @@ static GnomeUIInfo toolbar[] = {
 };
 
 int
-main (int argc, char *argv[]) {
+main (int argc, char *argv[])
+{
+	gchar *icon_file;
+
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 	
 	gnome_db_init("gnomedb-fe", VERSION, argc, argv);
 	fe_config_load();
 	
+	icon_file = gnome_pixmap_file("gnome-db.png");
+	gnome_window_icon_set_default_from_file(icon_file);
+
 	/* run application */
 	gnome_db_main((GtkFunction) prepare_app);
+	g_free((gpointer) icon_file);
+
 	return 0;
 }
 
 static guint
-prepare_app (void) {
+prepare_app (void)
+{
 	glb_mainwin = gnome_db_window_new("gnomedb-fe", mainmenu, toolbar, NULL);
 	gtk_signal_connect(GTK_OBJECT(glb_mainwin),
 	                   "close",
