@@ -19,25 +19,33 @@
 #if !defined(__gnomedb_fe_h__)
 #  define __gnomedb_fe_h__
 
+#include "config.h"
 #include <gnome.h>
 #include <gnome-db.h>
-#include <bonobo.h>
-
-#include <config.h>
+#if defined(HAVE_PERL)
+#  include "gnomedb-fe-perl.h"
+#endif
 
 BEGIN_GNOME_DECLS
 
 /*
  * Callbacks
  */
-void fe_about_cb              (GtkWidget *w, gpointer user_data);
-void fe_activate_component_cb (GtkWidget *w, gpointer user_data);
-void fe_do_copy_clipboard_cb  (GtkWidget *w, gpointer user_data);
-void fe_do_cut_clipboard_cb   (GtkWidget *w, gpointer user_data);
-void fe_do_paste_clipboard_cb (GtkWidget *w, gpointer user_data);
-void fe_do_print_cb           (GtkWidget *w, gpointer user_data);
-void fe_preferences_cb        (GtkWidget *w, gpointer user_data);
-void fe_quit_cb               (GtkWidget *w, gpointer user_data);
+void fe_about_cb                 (GtkWidget *w, gpointer user_data);
+void fe_activate_component_cb    (GtkWidget *w, gpointer user_data);
+void fe_do_copy_clipboard_cb     (GtkWidget *w, gpointer user_data);
+void fe_do_cut_clipboard_cb      (GtkWidget *w, gpointer user_data);
+void fe_do_paste_clipboard_cb    (GtkWidget *w, gpointer user_data);
+void fe_do_print_cb              (GtkWidget *w, gpointer user_data);
+void fe_new_database_cb          (GtkWidget *w, gpointer user_data);
+void fe_open_gnome_db_manual_cb  (GtkWidget *w, gpointer user_data);
+void fe_open_libgda_manual_cb    (GtkWidget *w, gpointer user_data);
+void fe_open_libgda_reference_cb (GtkWidget *w, gpointer user_data);
+void fe_preferences_cb           (GtkWidget *w, gpointer user_data);
+void fe_quit_cb                  (GtkWidget *w, gpointer user_data);
+#if defined(HAVE_PERL)
+void fe_run_perl_cb              (GtkWidget *w, gpointer user_data);
+#endif
 
 /*
  * Configuration
@@ -47,6 +55,11 @@ void fe_config_save        (void);
 
 void fe_config_open_dialog (void);
 
+/*
+ * Wizards
+ */
+void fe_wizard_new_database (void);
+
 /*
  * Work area
  */
@@ -64,11 +77,11 @@ extern GtkWidget*  glb_mainwin;
 /*
  * Configuration sections
  */
-#define GNOMEDB_FE_CONFIG_SECTION_MAIN "/gnomedb-fe"
-#define GNOMEDB_FE_CONFIG_SECTION_LOAD "/gnomedb-fe/Load"
+#define GNOMEDB_FE_CONFIG_SECTION_MAIN "/apps/gnome-db/Frontend"
+#define GNOMEDB_FE_CONFIG_SECTION_LOAD "/apps/gnome-db/Frontend/Load"
 
-#define GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS "/gnomedb-fe/General/SaveWindowPos"
+#define GNOMEDB_FE_CONFIG_KEY_SAVE_WINDOW_POS "/apps/gnome-db/Frontend/General/SaveWindowPos"
 
 END_GNOME_DECLS
 
-#endif
\ No newline at end of file
+#endif
