@@ -1210,7 +1210,7 @@ do_set_pixmap (BonoboUIHandlerPrivate *priv,
 	char    *parent_path;
 	BonoboUINode *node;
 	
-	parent_path = bonobo_ui_xml_get_parent_path (xml_path);
+	parent_path = (char *) bonobo_ui_xml_get_parent_path (xml_path);
 
 	node = bonobo_ui_component_get_tree (priv->component,
 					     xml_path, FALSE, NULL);
