@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2000 Rodrigo Moya
+ * Copyright (C) 1999-2001 Rodrigo Moya
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -20,7 +20,8 @@
 #ifndef __gnome_db_browser_h__
 #define __gnome_db_browser_h__ 1
 
-#include <gnome.h>
+#include <gtk/gtkvbox.h>
+#include <libgnome/gnome-defs.h>
 #include <gda-connection.h>
 #include <gda-recordset.h>
 
@@ -47,13 +48,13 @@ struct _GnomeDbBrowserClass {
 	void (*connection_changed)(GnomeDbBrowser *browser);
 };
 
-GtkType         gnome_db_browser_get_type       (void);
+GtkType        gnome_db_browser_get_type       (void);
 
-GtkWidget*      gnome_db_browser_new            (Gda_Connection *cnc);
-Gda_Connection* gnome_db_browser_get_connection (GnomeDbBrowser *browser);
-void            gnome_db_browser_set_connection (GnomeDbBrowser *browser, Gda_Connection *cnc);
+GtkWidget*     gnome_db_browser_new            (GdaConnection *cnc);
+GdaConnection* gnome_db_browser_get_connection (GnomeDbBrowser *browser);
+void           gnome_db_browser_set_connection (GnomeDbBrowser *browser, GdaConnection *cnc);
 
-void            gnome_db_browser_refresh        (GnomeDbBrowser *browser);
+void           gnome_db_browser_refresh        (GnomeDbBrowser *browser);
 
 END_GNOME_DECLS
 
