@@ -20,7 +20,8 @@
 #ifndef __gnome_db_combo_h__
 #define __gnome_db_combo_h__ 1
 
-#include <gnome.h>
+#include <gtk/gtkcombo.h>
+#include <libgnome/gnome-defs.h>
 #include <gda-recordset.h>
 
 BEGIN_GNOME_DECLS
@@ -34,25 +35,22 @@ BEGIN_GNOME_DECLS
 typedef struct _GnomeDbCombo GnomeDbCombo;
 typedef struct _GnomeDbComboClass GnomeDbComboClass;
 
-struct _GnomeDbCombo
-{
-  GtkCombo       combo;
-  Gda_Recordset* recset;
-  gint           total_rows;
-  gboolean       editable;
+struct _GnomeDbCombo {
+	GtkCombo       combo;
+	GdaRecordset* recset;
+	gint           total_rows;
+	gboolean       editable;
 };
 
-struct _GnomeDbComboClass
-{
-  GtkComboClass parent_class;
+struct _GnomeDbComboClass {
+	GtkComboClass parent_class;
 
-  void          (*error)            (GnomeDbCombo *dbcombo);
-  void          (*selection_changed)(GnomeDbCombo *dbcombo, gchar *sel);
+	void          (*error)            (GnomeDbCombo *dbcombo);
+	void          (*selection_changed)(GnomeDbCombo *dbcombo, gchar *sel);
 };
 
 guint          gnome_db_combo_get_type      (void);
-GtkWidget*     gnome_db_combo_new           (Gda_Recordset *recset, gint pos);
-void           gnome_db_combo_destroy       (GnomeDbCombo *dbcombo);
+GtkWidget*     gnome_db_combo_new           (GdaRecordset *recset, gint pos);
 
 gboolean       gnome_db_combo_get_editable  (GnomeDbCombo *dbcombo);
 void           gnome_db_combo_set_editable  (GnomeDbCombo *dbcombo, gboolean editable);
@@ -60,8 +58,8 @@ void           gnome_db_combo_set_editable  (GnomeDbCombo *dbcombo, gboolean edi
 void           gnome_db_combo_refresh       (GnomeDbCombo *dbcombo);
 gint           gnome_db_combo_get_row_count (GnomeDbCombo *dbcombo);
 gchar*         gnome_db_combo_get_string    (GnomeDbCombo *dbcombo);
-Gda_Recordset* gnome_db_combo_get_recordset (GnomeDbCombo *dbcombo);
-void           gnome_db_combo_set_recordset (GnomeDbCombo *dbcombo, Gda_Recordset *recset, gint pos);
+GdaRecordset* gnome_db_combo_get_recordset (GnomeDbCombo *dbcombo);
+void           gnome_db_combo_set_recordset (GnomeDbCombo *dbcombo, GdaRecordset *recset, gint pos);
 
 void           gnome_db_combo_sync          (GnomeDbCombo *dbcombo);
 
