@@ -18,8 +18,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <gnome-db.h>
-#include <GnomeDB.h>
+#include <bonobo/bonobo-object-directory.h>
+#include <libgnome/gnome-i18n.h>
+#include "gnome-db-control-widget.h"
+#include "gnome-db-config.h"
+#include "GnomeDB.h"
 
 /*
  * GnomeDbControlWidget object signals
@@ -34,7 +37,8 @@ static gint gnome_db_control_widget_signals[GNOME_DB_CONTROL_WIDGET_LAST_SIGNAL]
  * Callbacks
  */
 void
-focus_changed_cb (GtkWidget *w, GdkEventAny *event, GnomeDbControlWidget *wid) {
+focus_changed_cb (GtkWidget *w, GdkEventAny *event, GnomeDbControlWidget *wid)
+{
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	
 	if (GTK_WIDGET_HAS_FOCUS(wid->bonobo_widget)) gnome_db_control_widget_activate(wid);
@@ -45,12 +49,14 @@ focus_changed_cb (GtkWidget *w, GdkEventAny *event, GnomeDbControlWidget *wid) {
  * GnomeDbControlWidget object interface
  */
 static void
-gnome_db_control_widget_class_init (GnomeDbControlWidgetClass *klass) {
+gnome_db_control_widget_class_init (GnomeDbControlWidgetClass *klass)
+{
 	GtkObjectClass* object_class = GTK_OBJECT_CLASS(klass);
 }
 
 static void
-gnome_db_control_widget_init (GnomeDbControlWidget *widget) {
+gnome_db_control_widget_init (GnomeDbControlWidget *widget)
+{
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(widget));
 	
 	widget->bonobo_widget = NULL;
@@ -58,7 +64,8 @@ gnome_db_control_widget_init (GnomeDbControlWidget *widget) {
 }
 
 GtkType
-gnome_db_control_widget_get_type (void) {
+gnome_db_control_widget_get_type (void)
+{
 	static GtkType db_control_widget_type = 0;
 	
 	if (!db_control_widget_type) {
@@ -81,7 +88,8 @@ gnome_db_control_widget_get_type (void) {
  * gnome_db_control_widget_new
  */
 GtkWidget *
-gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic) {
+gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic)
+{
 	GnomeDbControlWidget* widget;
 	
 	g_return_val_if_fail(id != NULL, NULL);
@@ -121,7 +129,8 @@ gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic) {
 }
 
 static void
-gnome_db_control_widget_destroy (GnomeDbControlWidget *widget) {
+gnome_db_control_widget_destroy (GnomeDbControlWidget *widget)
+{
 	BonoboControlFrame* frame;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(widget));
@@ -134,7 +143,8 @@ gnome_db_control_widget_destroy (GnomeDbControlWidget *widget) {
 }
 
 gboolean
-gnome_db_control_widget_supported (const gchar *goad_id) {
+gnome_db_control_widget_supported (const gchar *goad_id)
+{
 	const gchar* ids[] = { "IDL:GNOME/DB/Control/Config:1.0", NULL };
 	GList*       servers, *list;
 	gboolean     found = FALSE;
@@ -154,7 +164,8 @@ gnome_db_control_widget_supported (const gchar *goad_id) {
  * gnome_db_control_widget_is_alive
  */
 gboolean
-gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid)
+{
 	BonoboControlFrame *control_frame;
 	CORBA_Object        corba_object;
 	CORBA_Environment   ev;
@@ -176,7 +187,8 @@ gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid) {
  * gnome_db_control_widget_activate
  */
 void
-gnome_db_control_widget_activate (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_activate (GnomeDbControlWidget *wid)
+{
 	BonoboControlFrame* control_frame;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -190,7 +202,8 @@ gnome_db_control_widget_activate (GnomeDbControlWidget *wid) {
  * gnome_db_control_widget_deactivate
  */
 void
-gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid)
+{
 	BonoboControlFrame* control_frame;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -205,7 +218,8 @@ gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid) {
  */
 gboolean 
 gnome_db_control_widget_prop_supported (GnomeDbControlWidget *wid, 
-                                        const gchar *prop_name) {
+                                        const gchar *prop_name)
+{
 	if (bonobo_property_bag_client_get_property(wid->prop, prop_name, NULL) != CORBA_OBJECT_NIL)
 		return TRUE;
 	else return FALSE;
@@ -214,7 +228,8 @@ gnome_db_control_widget_prop_supported (GnomeDbControlWidget *wid,
 void
 gnome_db_control_widget_set_prop_ptr (GnomeDbControlWidget *wid, 
                                       const gchar *prop_name,
-                                      gconstpointer value) {
+                                      gconstpointer value)
+{
 	CORBA_TypeCode ptype;
 	
 	ptype = bonobo_property_bag_client_get_property_type(wid->prop, prop_name, NULL);
@@ -242,7 +257,8 @@ gnome_db_control_widget_set_prop_ptr (GnomeDbControlWidget *wid,
 void
 gnome_db_control_widget_set_prop (GnomeDbControlWidget *wid, 
                                   const gchar *prop_name, 
-                                  ...) {
+                                  ...)
+{
 	CORBA_TypeCode ptype;
 	va_list pa;
 	gchar *mstr;
@@ -283,7 +299,8 @@ gnome_db_control_widget_set_prop (GnomeDbControlWidget *wid,
 void
 gnome_db_control_widget_get_prop (GnomeDbControlWidget *wid,
                                   const gchar *prop_name,
-                                  gpointer *value) {
+                                  gpointer *value)
+{
 	CORBA_TypeCode ptype;
 	
 	ptype = bonobo_property_bag_client_get_property_type(wid->prop, prop_name, NULL);
@@ -318,7 +335,8 @@ gnome_db_control_widget_get_prop (GnomeDbControlWidget *wid,
  *
  */
 static CORBA_Object
-gnome_db_control_widget_get_gnomedb_control (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_get_gnomedb_control (GnomeDbControlWidget *wid)
+{
 	CORBA_Environment ev;
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid), CORBA_OBJECT_NIL);
@@ -346,7 +364,8 @@ gnome_db_control_widget_get_gnomedb_control (GnomeDbControlWidget *wid) {
  * Return the version supported by the underlying control.
  */
 gchar *
-gnome_db_control_widget_get_version (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_get_version (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid), NULL);
@@ -371,7 +390,8 @@ gnome_db_control_widget_get_version (GnomeDbControlWidget *wid) {
  * gnome_db_control_instance_get_authors
  */
 gchar *
-gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid) {
+gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid), NULL);
@@ -397,7 +417,8 @@ gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid) {
  * @wid: control widget
  */
 void
-gnome_db_control_widget_run (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_run (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -418,7 +439,8 @@ gnome_db_control_widget_run (GnomeDbControlWidget *wid) {
  * @wid: control widget
  */
 void
-gnome_db_control_widget_do_print (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_do_print (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -439,7 +461,8 @@ gnome_db_control_widget_do_print (GnomeDbControlWidget *wid) {
  * @wid: control widget
  */
 void
-gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -460,7 +483,8 @@ gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid) {
  * @wid: control widget
  */
 void
-gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
@@ -481,7 +505,8 @@ gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid) {
  * @wid: control widget
  */
 void
-gnome_db_control_widget_do_paste_clipboard (GnomeDbControlWidget *wid) {
+gnome_db_control_widget_do_paste_clipboard (GnomeDbControlWidget *wid)
+{
 	GNOME_DB_Control gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
