@@ -21,7 +21,8 @@
 #if !defined(__gnome_db_control_widget_h__)
 #  define __gnome_db_control_widget_h__
 
-#include <bonobo.h>
+#include <gtk/gtkvbox.h>
+#include <bonobo/bonobo-widget.h>
 #include <gnome-db-control-defprops.h>
 
 BEGIN_GNOME_DECLS
