@@ -17,13 +17,18 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(HAVE_CONFIG_H)
-#  include <config.h>
-#endif
-#include "gnome-db.h"
+#include "config.h"
+#include "gnome-db-dataset.h"
+#include "gnome-db-grid.h"
+#include "gnome-db-util.h"
+#include <libgnome/gnome-i18n.h>
+#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-dialog.h>
 
 static void gnome_db_grid_class_init (GnomeDbGridClass *);
-static void gnome_db_grid_init       (GnomeDbGrid *);
+static void gnome_db_grid_init (GnomeDbGrid *);
+
+static void gnome_db_grid_destroy (GtkObject *object);
 
 /*
  * GnomeDbGrid widget signals
@@ -259,7 +264,7 @@ timeout_callback (GnomeDbGrid *grid)
       gtk_clist_freeze(GTK_CLIST(grid->grid));
       for (cnt = 0; cnt < gda_recordset_rowsize(grid->recset); cnt++)
         {
-          Gda_Field *field = gda_recordset_field_idx(grid->recset, cnt);
+          GdaField *field = gda_recordset_field_idx(grid->recset, cnt);
           g_ptr_array_add(row, (gpointer) gda_stringify_value(0, 0, field));
         }
       gtk_clist_append(GTK_CLIST(grid->grid), (gchar **) row->pdata);
@@ -284,7 +289,7 @@ timeout_callback (GnomeDbGrid *grid)
 }
 
 static void
-show_recordset (GnomeDbGrid *grid, Gda_Recordset *recset)
+show_recordset (GnomeDbGrid *grid, GdaRecordset *recset)
 {
   gulong position;
   register gint cnt, total_fields = 0;
@@ -453,7 +458,7 @@ gnome_db_grid_get_type (void)
  * Returns: a pointer to the new widget, or NULL on error
  */
 GtkWidget *
-gnome_db_grid_new (Gda_Recordset *recset)
+gnome_db_grid_new (GdaRecordset *recset)
 {
   GtkWidget *grid;
   grid = gtk_type_new(gnome_db_grid_get_type());
@@ -465,19 +470,15 @@ gnome_db_grid_new (Gda_Recordset *recset)
   return (grid);
 }
 
-/**
- * gnome_db_destroy
- * @grid: the grid to be destroyed
- *
- * Destroys the given grid, freeing any data associated with it, included
- * the Gda_Recordset object
- */
-void
-gnome_db_grid_destroy (GnomeDbGrid *grid)
+static void
+gnome_db_grid_destroy (GtkObject *object)
 {
-  g_return_if_fail(grid != NULL);
-  g_return_if_fail(GNOME_DB_IS_GRID(grid));
+  GnomeDbGrid *grid;
   
+  g_return_if_fail(GNOME_DB_IS_GRID(object));
+  
+  grid = GNOME_DB_GRID(object);
+
   /* stop timeout if active */
   if (grid->timeout_handle != -1)
     gtk_timeout_remove(grid->timeout_handle);
@@ -724,12 +725,12 @@ gnome_db_grid_refresh (GnomeDbGrid *grid)
  * gnome_db_grid_get_recordset
  * @grid: the grid widget
  *
- * Returns the Gda_Recordset object being used by this grid
+ * Returns the GdaRecordset object being used by this grid
  *
- * Returns: a pointer to the Gda_Recordsetobject, or NULL if none is being
+ * Returns: a pointer to the GdaRecordsetobject, or NULL if none is being
  * used or if there is an error
  */
-Gda_Recordset *
+GdaRecordset *
 gnome_db_grid_get_recordset (GnomeDbGrid *grid)
 {
   g_return_val_if_fail(grid != NULL, NULL);
@@ -745,7 +746,7 @@ gnome_db_grid_get_recordset (GnomeDbGrid *grid)
  * Sets the recordset to be displayed on the given grid
  */
 void
-gnome_db_grid_set_recordset (GnomeDbGrid *grid, Gda_Recordset *recset)
+gnome_db_grid_set_recordset (GnomeDbGrid *grid, GdaRecordset *recset)
 {
   g_return_if_fail(grid != NULL);
   g_return_if_fail(GNOME_DB_IS_GRID(grid));
