@@ -1,5 +1,9 @@
-/* GNOME DB libary
- * Copyright (C) 1998,1999 Michael Lausch
+/* GNOME DB library
+ * Copyright (C) 1998-2001 The Free Software Foundation
+ *
+ * Authors:
+ *	Michael Lausch <michael@lausch.at>
+ *	Rodrigo Moya <rodrigo@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -17,13 +21,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __gda_dblogindlg_h__
-#define __gda_dblogindlg_h__ 1
+#ifndef __gnome_db_logindlg_h__
+#define __gnome_db_logindlg_h__ 1
 
-#include <gnome.h>
+#include <libgnomeui/gnome-dialog.h>
 #include <gda-connection.h>
-#include "gnome-db-error-dlg.h"
-#include "gnome-db-login.h"
+#include <gnome-db-error-dlg.h>
+#include <gnome-db-login.h>
 
 BEGIN_GNOME_DECLS
 
@@ -38,16 +42,16 @@ typedef struct _GnomeDbLoginDlgClass      GnomeDbLoginDlgClass;
 
 struct _GnomeDbLoginDlg
 {
-  GnomeDialog      dialog;
-  GnomeDbLogin*    login;
-  GnomeDbErrorDlg* error;
+	GnomeDialog      dialog;
+	GnomeDbLogin*    login;
+	GnomeDbErrorDlg* error;
 };
 
 struct _GnomeDbLoginDlgClass
 {
-  GnomeDialogClass parent_class;
-  void             (*login)(GnomeDbLoginDlg* login);
-  void             (*cancel)(GnomeDbLoginDlg* login);
+	GnomeDialogClass parent_class;
+	void             (*login)(GnomeDbLoginDlg* login);
+	void             (*cancel)(GnomeDbLoginDlg* login);
 };
 
 GtkType    gnome_db_logindlg_get_type (void);
